<h1 align="center">
  <a href="https://anbai106.github.io/mlni/">
    <img src="https://anbai106.github.io/mlni/images/mlni.png" alt="mlni Logo">
  </a>
  <br/>
  MLNI
</h1>

<p align="center"><strong>Machine Learning in NeuroImaging</strong></p>

<p align="center">
  <a href="https://anbai106.github.io/mlni/">Documentation</a>
</p>

## `MLNI`
MLNI is a python package that performs various tasks using neuroimaging data: i) binary classification for disease diagnosis, following good practice proposed in [AD-ML](https://github.com/aramis-lab/AD-ML); ii) regression prediction, such as age prediction; and iii) semi-supervised clustering with [HYDRA](https://github.com/evarol/HYDRA).

## Citing this work
> :warning: Please let me know if you use this package for your publication; I will update your papers in the section of **Publication using MLNI**...

> :warning: Please cite the software using the **Cite this repository** button on the right sidebar menu, as well as the original papers below for different tasks...

### If you use this software for classification:
> Wen, J., 2020. **Reproducible evaluation of diffusion MRI features for automatic classification of patients with Alzheimer’s disease**. Neuroinformatics, pp.1-22. [doi:10.1007/s12021-020-09469-5](https://link.springer.com/article/10.1007/s12021-020-09469-5) - [Paper in PDF](https://arxiv.org/abs/1812.11183)

### If you use this software for regression:
> Wen, J., 2024. **The Genetic Architecture of Multimodal Human Brain Age**. Nature Communications, pp.1-22. [10.1038/s41467-024-46796-6](https://www.nature.com/articles/s41467-024-46796-6) - [Paper in PDF](https://www.nature.com/articles/s41467-024-46796-6)

### If you use this software for clustering:
> Varol, E., 2017. **HYDRA: Revealing heterogeneity of imaging and genetic patterns through a multiple max-margin discriminative analysis framework**. Neuroimage, 145, pp.346-364. [doi:10.1016/j.neuroimage.2016.02.041](https://www.sciencedirect.com/science/article/abs/pii/S1053811916001506?via%3Dihub) - [Paper in PDF](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5408358/pdf/nihms762663.pdf)

## Publication using MLNI
> Wen, J., 2021. **Multi-scale semi-supervised clustering of brain images: deriving disease subtypes**. MedIA. - [Link](https://www.sciencedirect.com/science/article/abs/pii/S1361841521003492)

> Wen, J., 2022. **Characterizing Heterogeneity in Neuroimaging, Cognition, Clinical Symptoms, and Genetics Among Patients With Late-Life Depression**. JAMA Psychiatry -  [Link](https://jamanetwork.com/journals/jamapsychiatry/article-abstract/2789902)

> Lalousis, P.A., 2022. **Neurobiologically Based Stratification of Recent Onset Depression and Psychosis: Identification of Two Distinct Transdiagnostic Phenotypes**. Biological Psychiatry. -  [Link](https://www.sciencedirect.com/science/article/pii/S0006322322011568#bib50)
